@@ -16,7 +16,6 @@ import pandas as pd
 import shutil
 import logging
 import hashlib
-from SigProfilerMatrixGenerator.scripts import convert_input_to_simple_files as convertIn
 from SigProfilerMatrixGenerator.scripts import SigProfilerMatrixGeneratorFunc as matGen
 import glob
 
@@ -140,6 +139,9 @@ check_sum = {'GRCh37':
 					 'XIII':'a12878f65ed7464e2824cb0c291d359e', 'XIV':'807431901ba993e6ba87861401da1cb2', 'XV':'44fd7223d9d30bdcf94cf627e5a172ca',
 					 'XVI':'670d7aad863043ea7a125f004e281483'}}
 
+def get_reference_md5():
+	return check_sum
+
 def md5(fname):
 	hash_md5 = hashlib.md5()
 	with open(fname, "rb") as f:
